@@ -1,5 +1,5 @@
 "eff.ridge" <-
-function (form, data, rscale = 1, steps = 8, ...) 
+function (form, data, rscale = 1, steps = 20, ...) 
 { 
     if (missing(form) || class(form) != "formula") 
         stop("First argument to eff.ridge must be a valid linear regression formula.") 
@@ -210,17 +210,17 @@ function (x, trace = "all", trkey = FALSE, ...)
     mV <- x$mStar    # Optimal m-extent in eff.ridge()... 
     opar <- par(no.readonly = TRUE) 
     on.exit(par(opar)) 
+    myty <- c(1,2,4,5,6,7,8,9,10,11,12,3)        # KEY CHANGE: lty == 3 (dotted line) is moved to 12th position...
     if (trace == "all") par(mfrow=c(3,2)) else 
         par(mfrow=c(1,1)) 
     if (trace == "all" || trace == "seq" || trace == "coef") { 
         plot(mcalp, x$coef, ann = FALSE, type = "n") 
         abline(v = mV, col = "gray", lty = 2, lwd = 2) 
         abline(h = 0, col = gray(0.9), lwd = 2) 
-        for (i in 1:x$p) lines(mcal, x$coef[, i], col = i, lty = i, 
-            lwd = 2) 
+        for (i in 1:x$p) lines(mcal, x$coef[, i], col = i, lty = myty[i], lwd = 2) 
         title(main = paste("COEFFICIENT TRACE"), 
             xlab = "m = Multicollinearity Allowance", ylab = "Fitted Coefficients") 
-        if(trkey) legend("bottom", all.vars(x$form)[2:(x$p+1)], col=1:(x$p), lty=1:(x$p), lwd=2) 
+        if(trkey) legend("bottomright", all.vars(x$form)[2:(x$p+1)], col=1:(x$p), lty=myty[1:(x$p)], lwd=2) 
     } 
     if (trace == "seq") {
         cat("\nPress the Enter key to view the RMSE trace...") 
@@ -230,11 +230,11 @@ function (x, trace = "all", trkey = FALSE, ...)
         plot(mcalp, x$rmse, ann = FALSE, type = "n") 
         abline(v = mV, col = "gray", lty = 2, lwd = 2) 
         abline(h = 0, col = gray(0.9), lwd = 2) 
-        for (i in 1:x$p) lines(mcal, x$rmse[, i], col = i, lty = i, 
+        for (i in 1:x$p) lines(mcal, x$rmse[, i], col = i, lty = myty[i], 
             lwd = 2) 
         title(main = paste("RELATIVE MSE"), 
             xlab = "m = Multicollinearity Allowance", ylab = "Scaled MSE Risk") 
-        if (trkey) legend("bottom", all.vars(x$form)[2:(x$p+1)], col=1:(x$p), lty=1:(x$p), lwd=2) 
+        if (trkey) legend("bottomright", all.vars(x$form)[2:(x$p+1)], col=1:(x$p), lty=myty[1:(x$p)], lwd=2) 
     } 
     if (trace == "seq") { 
         cat("\nPress the Enter key to view the EXEV trace...") 
@@ -244,11 +244,10 @@ function (x, trace = "all", trkey = FALSE, ...)
         plot(mcalp, x$exev, ann = FALSE, type = "n") 
         abline(v = mV, col = "gray", lty = 2, lwd = 2) 
         abline(h = 0, col = gray(0.9), lwd = 2) 
-        for (i in 1:x$p) lines(mcal, x$exev[, i], col = i, lty = i, 
-            lwd = 2) 
+        for (i in 1:x$p) lines(mcal, x$exev[, i], col = i, lty = myty[i], lwd = 2) 
         title(main = paste("EXCESS EIGENVALUES"), 
-            xlab = "m = Multicollinearity Allowance", ylab = "Least Squares minus UNRes") 
-        if (trkey) legend("bottom", paste("Component", 1:(x$p)), col=1:(x$p), lty=1:(x$p), lwd=2) 
+            xlab = "m = Multicollinearity Allowance", ylab = "Least Squares minus EffGRR") 
+        if (trkey) legend("bottomright", paste("Component", 1:(x$p)), col=1:(x$p), lty=myty[1:(x$p)], lwd=2) 
     } 
     if (trace == "seq") { 
         cat("\nPress the Enter key to view the INFD trace...") 
@@ -258,11 +257,10 @@ function (x, trace = "all", trkey = FALSE, ...)
         plot(mcalp, x$infd, ann = FALSE, type = "n", ylim = c(-1,1)) 
         abline(v = mV, col = "gray", lty = 2, lwd = 2) 
         abline(h = 0, col = gray(0.9), lwd = 2) 
-        for (i in 1:x$p) lines(mcal, x$infd[, i], col = i, lty = i, 
-            lwd = 2) 
+        for (i in 1:x$p) lines(mcal, x$infd[, i], col = i, lty = myty[i], lwd = 2) 
         title(main = paste("INFERIOR DIRECTION"), 
             xlab = "m = Multicollinearity Allowance", ylab = "Direction Cosines") 
-        if(trkey) legend("bottom", all.vars(x$form)[2:(x$p+1)], col=1:(x$p), lty=1:(x$p), lwd=2) 
+        if(trkey) legend("bottomright", all.vars(x$form)[2:(x$p+1)], col=1:(x$p), lty=myty[1:(x$p)], lwd=2) 
     } 
     if (trace == "seq") { 
         cat("\nPress the Enter key to view the SPAT trace...") 
@@ -272,11 +270,10 @@ function (x, trace = "all", trkey = FALSE, ...)
         plot(mcalp, x$spat, ann = FALSE, type = "n") 
         abline(v = mV, col = "gray", lty = 2, lwd = 2) 
         abline(h = 0, col = gray(0.9), lwd = 2) 
-        for (i in 1:x$p) lines(mcal, x$spat[, i], col = i, lty = i, 
-            lwd = 2) 
+        for (i in 1:x$p) lines(mcal, x$spat[, i], col = i, lty = myty[i], lwd = 2) 
         title(main = paste("SHRINKAGE PATTERN"), 
-            xlab = "m = Multicollinearity Allowance", ylab = "UNRes Delta Factors") 
-        if(trkey) legend("bottom", paste("Component", 1:(x$p)), col=1:(x$p), lty=1:(x$p), lwd=2) 
+            xlab = "m = Multicollinearity Allowance", ylab = "Shrinkage Delta-Factors") 
+        if(trkey) legend("bottomright", paste("Component", 1:(x$p)), col=1:(x$p), lty=myty[1:(x$p)], lwd=2) 
     }
 }
 
